package com.mortals.xhx.module.dept.web;

import com.mortals.xhx.base.system.param.service.ParamService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.bind.annotation.*;
import com.mortals.framework.model.Context;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.mortals.framework.web.BaseCRUDJsonPhpController;
import com.mortals.xhx.module.dept.model.DeptEntity;
import com.mortals.xhx.module.dept.model.DeptQuery;
import com.mortals.xhx.module.dept.service.DeptService;
import org.apache.commons.lang3.ArrayUtils;
import com.mortals.framework.util.StringUtils;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import java.util.Arrays;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import static com.mortals.framework.ap.SysConstains.*;
/**
 *
 * 部门
 *
 * @author zxfei
 * @date 2022-01-20
 */
@RestController
@RequestMapping("dept")
public class DeptController extends BaseCRUDJsonPhpController<DeptService,DeptForm,DeptEntity,Long> {

    @Autowired
    private ParamService paramService;

    public DeptController(){
        super.setFormClass(DeptForm.class);
        super.setModuleDesc( "部门");
    }

    @Override
    protected void init(HttpServletRequest request, HttpServletResponse response, DeptForm form, Map<String, Object> model, Context context) {
        this.addDict(model, "isAutotable", paramService.getParamBySecondOrganize("Dept","isAutotable"));
        this.addDict(model, "isOrder", paramService.getParamBySecondOrganize("Dept","isOrder"));
        this.addDict(model, "isBkb", paramService.getParamBySecondOrganize("Dept","isBkb"));
        this.addDict(model, "isWorkGuide", paramService.getParamBySecondOrganize("Dept","isWorkGuide"));
        this.addDict(model, "usValid", paramService.getParamBySecondOrganize("Dept","usValid"));
        this.addDict(model, "isSecphone", paramService.getParamBySecondOrganize("Dept","isSecphone"));
        this.addDict(model, "isEnglish", paramService.getParamBySecondOrganize("Dept","isEnglish"));
        super.init(request, response, form, model, context);
    }

    /**
     * 查询部门
     */
    @PostMapping(value = "list")
    public String list(@RequestBody DeptQuery query) {
        try {
            DeptForm form = new DeptForm();
            form.setQuery(query);
            return super.list(form);
        } catch (Exception e) {
            log.error("查询部门列表错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 新增部门
     */
    @PostMapping(value = "add")
    public String add() {
        try {
            DeptForm form = new DeptForm();
            return super.add(form);
        } catch (Exception e) {
            log.error("新增部门错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 编辑部门
     */
    @GetMapping(value = "edit")
    public String edit(Long id) {
        try {
            DeptForm form = new DeptForm();
            form.setId(new Long[]{id});
            return super.edit(form);
        } catch (Exception e) {
            log.error("部门模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 保存部门
     */
    @PostMapping(value = "save")
    public String save(@RequestBody DeptEntity entity) {
        try {
            DeptForm form = new DeptForm();
            form.setDept(entity);
            return super.save(form);
        } catch (Exception e) {
            log.error("部门模块错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 删除部门
     */
    @GetMapping(value = "delete")
    public String delete(String id) {
        try {
            DeptForm form = new DeptForm();
            String[] split = id.split(",");
            Long[] ids = Arrays.asList(split).stream().map(Long::parseLong).toArray(Long[]::new);
            form.setId(ids);
            return super.delete(form);
        } catch (Exception e) {
            log.error("删除部门错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 查看部门
     */
    @GetMapping(value = "info")
    public String info(Long id) {
        try {
            DeptForm form = new DeptForm();
            form.setId(new Long[]{id});
            return super.view(form);
        } catch (Exception e) {
            log.error("查看部门错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }


    /**
     * 部门导入模板下载
     */
    @PostMapping(value = "downloadTemplate")
    public void downloadTemplate() {
        try {
            super.downloadTemplate();
        } catch (Exception e) {
            log.error("部门导入模板下载错误", e);
        }
    }

    /**
     * 部门导出
     */
    @PostMapping(value = "importData")
    public String importData(MultipartFile file, boolean updateSupport) {
        try {
            return super.importData(file, updateSupport);
        } catch (Exception e) {
            log.error("部门导入错误", e);
            JSONObject ret = new JSONObject();
            ret.put(KEY_RESULT_CODE, VALUE_RESULT_FAILURE);
            ret.put(KEY_RESULT_MSG, super.convertException(e));
            return ret.toJSONString();
        }
    }

    /**
     * 部门导出
     */
    @PostMapping("exportExcel")
    public void exportExcel(@RequestBody DeptQuery query) {
        try {
            DeptForm form = new DeptForm();
            form.setQuery(query);
            super.exportExcel(form);
        } catch (Exception e) {
            log.error("部门导出错误", e);
        }
    }
}